==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebTreeSelectionOptionsEventDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebTreeSelectionOptionsEventDetailDescription = /*@__PURE__*/ (() => {
    class WebTreeSelectionOptionsEventDetailDescription extends Description {
        constructor() {
            super();
            this.f = null;
        }
        get_type() {
            return "WebTreeSelectionOptionsEventDetail";
        }
        get type() {
            return this.get_type();
        }
        get newSelection() {
            return this.f;
        }
        set newSelection(a) {
            this.f = a;
            this.e("NewSelection");
        }
    }
    WebTreeSelectionOptionsEventDetailDescription.$t = /*@__PURE__*/ markType(WebTreeSelectionOptionsEventDetailDescription, 'WebTreeSelectionOptionsEventDetailDescription', Description.$);
    WebTreeSelectionOptionsEventDetailDescription.__marshalByValue = true;
    WebTreeSelectionOptionsEventDetailDescription.__marshalByValueAlias = "TreeSelectionOptionsEventDetail";
    return WebTreeSelectionOptionsEventDetailDescription;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebTreeSelectionOptionsEventDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebTreeSelectionOptionsEventDetailDescription = /*@__PURE__*/ (() => {
    class WebTreeSelectionOptionsEventDetailDescription extends Description {
        get_type() {
            return "WebTreeSelectionOptionsEventDetail";
        }
        get type() {
            return this.get_type();
        }
        constructor() {
            super();
            this.h = null;
        }
        get newSelection() {
            return this.h;
        }
        set newSelection(a) {
            this.h = a;
            this.g("NewSelection");
        }
    }
    WebTreeSelectionOptionsEventDetailDescription.$t = /*@__PURE__*/ markType(WebTreeSelectionOptionsEventDetailDescription, 'WebTreeSelectionOptionsEventDetailDescription', Description.$);
    WebTreeSelectionOptionsEventDetailDescription.__marshalByValue = true;
    WebTreeSelectionOptionsEventDetailDescription.__marshalByValueAlias = "TreeSelectionOptionsEventDetail";
    return WebTreeSelectionOptionsEventDetailDescription;
})();
